@@ -12,12 +12,13 @@ import sys
 from tornado import iostream
 from tornado.options import options
 
+from blackhole import __fullname__
 from blackhole.state import MailState
 from blackhole.data import response, EHLO_RESPONSES
 from blackhole.opts import ports
 from blackhole.ssl_utils import sslkwargs
 from blackhole.log import log
-from blackhole.utils import email_id
+from blackhole.utils import email_id, get_mailname
 
 
 def sockets():
@@ -98,8 +99,11 @@ def handle_command(line, mail_state):
         if line[0] == "." and len(line) == 3 and ord(line[0]) == 46:
             mail_state.reading = False
             resp = response()
+            from tornado.ioloop import IOLoop
+            import time
+            IOLoop.instance().add_timeout(time.time() + 5, time.time())
     elif line.lower().startswith("ehlo"):
-        resp = ["%s\n" % x for x in EHLO_RESPONSES]
+        resp = ["%s\r\n" % x for x in EHLO_RESPONSES]
     elif any(line.lower().startswith(e) for e in ['helo', 'mail from',
                                                   'rcpt to', 'noop']):
         resp = response(250)
@@ -123,12 +127,21 @@ def handle_command(line, mail_state):
         mail_state.reading = True
     else:
         resp = response(500)
+    
+    # this is a blocking action, sadly
+    # async non blocking methods did not
+    # work. =(
+    if options.delay > 0:
+        # import has to be called here for
+        # some reason...
+        import time
+        time.sleep(options.delay)
     return resp, close
 
 
 def write_response(stream, mail_state, resp):
     """Write the response back to the stream"""
-    log.debug("[%s] SEND: %s" % (mail_state.email_id, resp.rstrip()))
+    log.debug("[%s] SEND: %s" % (mail_state.email_id, resp.upper().rstrip()))
     stream.write(resp)
 
 
@@ -191,5 +204,7 @@ def connection_ready(sock, fd, events):
             """
             stream.read_until("\n", handle)
 
-        stream.write(response(220))
+        hm = "220 %s [%s]\r\n" % (get_mailname(),
+                              __fullname__)
+        stream.write(hm)
         loop()
